@@ -4,7 +4,7 @@
 # unsnoopable.pl - Completely unsnoopable messaging
 # Copyright (c) 2017 Ashish Gulhati <crypt-unsnoopable at hash.neo.tc>
 #
-# $Id: bin/unsnoopable.pl v1.005 Mon Jun 19 00:36:53 PDT 2017 $
+# $Id: bin/unsnoopable.pl v1.006 Tue Jun 20 15:40:10 PDT 2017 $
 
 use warnings;
 
@@ -22,9 +22,6 @@ unless (-d $UNSNOOPABLE) {
 }
 
 my $u = new Crypt::Unsnoopable (DB => $UNSNOOPABLE);
-
-# Get pads, default to first one
-
 my $pads = $u->otps;
 
 # Initialize l8n
@@ -42,7 +39,7 @@ $action{Generate} = sub {   # Generate new OTP
   my $name = $dialog->GetValue(); return unless $name =~ /^[\w\d\s]+$/; return if exists $pads->{$name};
   my $pad = $u->otpgen(2935, $name);
   $pads = $u->otps;
-  $padsel->Insert($name, 0);
+  $padsel->Insert("$name (2935)", 0);
   show();
 };
 
@@ -54,9 +51,9 @@ $action{Import} = sub {     # Import OTP
   $dialog = Wx::TextEntryDialog->new( $frame, "Enter a name for this pad:", "Import One-Time Pad");
   return if $dialog->ShowModal == wxID_CANCEL;
   my $name = $dialog->GetValue(); return unless $name =~ /^[\w\d\s]+$/; return if exists $pads->{$name};
-  return unless $u->add($pad, $name);
-  $pads = $u->otps;
-  $padsel->Insert($name, 0);
+  return unless my $pad = $u->add($pad, $name);
+  $pads = $u->otps; my $len = length($pads->{$name}->{pad})/2;
+  $padsel->Insert("$name ($len)", 0);
   show();
 };
 
@@ -448,8 +445,8 @@ unsnoopable.pl - Completely unsnoopable messaging
 
 =head1 VERSION
 
- $Revision: 1.005 $
- $Date: Mon Jun 19 00:36:53 PDT 2017 $
+ $Revision: 1.006 $
+ $Date: Tue Jun 20 15:40:10 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -457,17 +454,87 @@ unsnoopable.pl - Completely unsnoopable messaging
 
 =head1 DESCRIPTION
 
-unsnoopable.pl is a simple application for end-to-end completely
-unsnoopable messaging. It is intended to be run on an offline device
-that is never connected to any networks and has no wireless networking
-hardware. It uses one time pads (OTPs) for completely unbreakable
-encryption.
+unsnoopable.pl (Unsnoopable) is a simple application for end-to-end
+completely unsnoopable messaging. It is intended to be run on
+air-gapped devices that are never connected to any networks and have
+no wireless networking hardware. Unsnoopable uses one-time pads (OTPs)
+for completely unbreakable encryption.
+
+Unsnoopability goes further than unbreakability of encryption however,
+as a compromised device can leak plaintext even when the encryption
+used to transmit the message is unbreakable. This is the reason
+Unsnoopable is designed for use on an air-gapped devices, with a
+screen, text input capability, and a camera.
+
+A new one-time pad can be generated by clicking the Generate button,
+and providing a name for the pad. The OTP can then be Exported by
+displaying it on the device's screen as a QR code. It can be Imported
+into the corresponding device of the person one wishes to communicate
+unsnoopably with, by scanning it using a camera and a QR code
+recognition software such as Zbar. Unsnoopable doesn't currently
+feature QR code scanning within the application.
+
+To send a message, one selects an OTP from the list at the top of the
+application window, and clicks Send. A message can then be typed in,
+and it will be encrypted using the selected OTP, and displayed as a QR
+code for scanning. The QR code can be scanned from the screen of the
+air-gapped device using a regular connected smartphone and any mobile
+QR code scanning app. The scanned string can then be sent to the
+recipient using any communications medium.
+
+The receipient can display the received message as a QR code on their
+own smartphone screen, scan it into their own air-gapped device (which
+already has the OTP shared previously) and click Receive to input the
+ciphertext string and view the decrypted message.
+
+This provides not only theoretically unbreakable encryption for the
+message using OTP encryption, but also complete air-gapped security
+for the devices where the plaintext and OTPs are stored. In effect
+this is complete and total unsnoopability for the message over the
+network both while in transit, and from any network-based attacks
+against the recipient devices.
+
+As with all security systems, though, there are still some caveats:
+
+Obviously Unsnoopable can't and doesn't protect against physical
+attacks where the attacker has access to any of the devices on which
+the OTPs are stored, or visual access that would enable them to view
+the messages or pads on the device screens, or proximity access that
+would enable attacks based on leakage via electromagnetic radiation,
+or audio access via bugs / smartphone microphones (if the message is
+spoken out aloud), etc.
+
+Physical access to the OTPs can be protected by storing them on
+MicroSD cards, which are small and relatively easy to keep physically
+secure. A small single board computer such as a Raspberry Pi would be
+an excellent option to deploy Unsnoopable on, as it features a MicroSD
+card reader and boots off the MicroSD card itself. Keeping the boot OS
+secure is also important - an attacker with access to the air-gapped
+machine's OS could put in trojans to surreptitiously save OTPs or
+plaintexts for later retrieval.
+
+There's also a suitable camera module available for use with the Pi,
+as well as a variety of suitable small LCD screens. Indeed Unsnoopable
+was designed with Pi-based deployment in mind, specifically on models
+that don't have wireless networking hardware, such as the (non-W) Pi
+Zero.
+
+The current implementation uses the L<Bytes::Random::Secure> module to
+source random numbers for the one-time pads. This module uses a CSPRNG
+to generate random numbers, and isn't a truly random source. For
+really unbreakable encryption, a source of true random numbers should
+be used. A few devices that generate true random numbers are available
+commercially.
+
+The pad length is currently set to a fixed size that is communicable
+in a single QR code. This limitation will be removed in future
+versions of the app.
 
 =head1 SEE ALSO
 
-=head2 www.unsnoopable.org
+=head2 L<http://www.unsnoopable.org>
 
-=head2
+=head2 L<Crypt::Unsnoopable>
 
 =head1 AUTHOR
 
